import { useState, useEffect } from 'react'
import { useParams, Link, useNavigate } from 'react-router-dom'
import axios from 'axios'
import { format } from 'date-fns'
import './Post.css'

function Post() {
  const { slug } = useParams()
  const navigate = useNavigate()
  const [post, setPost] = useState(null)
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState(null)

  useEffect(() => {
    const fetchPost = async () => {
      try {
        const response = await axios.get(`http://localhost:5000/api/posts/${slug}`)
        setPost(response.data)
        setLoading(false)
      } catch (err) {
        console.error(`Error fetching post with slug ${slug}:`, err)
        setError('Post not found or unable to load.')
        setLoading(false)
      }
    }

    fetchPost()
  }, [slug])

  if (loading) return <div className="loading">Loading post...</div>
  if (error) return <div className="error">{error}</div>
  if (!post) return <div className="error">Post not found</div>

  return (
    <div className="post-page">
      <div className="container">
        <article className="post">
          <header className="post-header">
            <h1>{post.title}</h1>
            <div className="post-meta">
              <time>{format(new Date(post.date), 'MMMM d, yyyy')}</time>
              {post.tags && (
                <div className="post-tags">
                  {post.tags.map(tag => (
                    <Link key={tag} to={`/blog?tag=${tag}`} className="tag">
                      {tag}
                    </Link>
                  ))}
                </div>
              )}
            </div>
          </header>
          
          <div 
            className="post-content"
            dangerouslySetInnerHTML={{ __html: post.content }}
          />
          
          <footer className="post-footer">
            <div className="post-navigation">
              <Link to="/blog" className="back-to-blog">
                ← Back to Blog
              </Link>
            </div>
          </footer>
        </article>
      </div>
    </div>
  )
}

export default Post